@@ -36,8 +36,8 @@ setMethod(f = "start",signature(.Object = "geojob"),definition = function(.Objec
 	requestXML <- xml(.Object)
 	data <- genericExecute(url = url(.Object), requestXML)
 	xmltext <- gcontent(data)
-	response <- xmlRoot(xmltext)
-	processID <- xmlGetAttr(response,"statusLocation")
+	response <- xml2::xml_root(xmltext)
+	processID <- xml2::xml_attr(response,"statusLocation")
 	
 	id(.Object)	<-	processID
   setJobState("ProcessStarted")
